@@ -5,7 +5,6 @@ extern crate test;
 
 mod to_html {
     use pulldown_cmark::{Parser, Options, html};
-    use std::str::from_utf8;
 
     fn render_html(text: &str, opts: Options) -> String {
         let mut s = String::with_capacity(text.len() * 3 / 2);
@@ -14,14 +13,6 @@ mod to_html {
         s
     }
 
-    #[bench]
-    fn crdt_empty_options(b: &mut test::Bencher) {
-        let input_bytes = include_bytes!("../third_party/xi-editor/crdt.md");
-        let input = from_utf8(input_bytes).unwrap();
-
-        b.iter(|| render_html(&input, Options::empty()));
-    }
-
     #[bench]
     fn paragraph_lots_unescapes(b: &mut test::Bencher) {
         let input = "This is by far my favourite unicode code point: &#xAAA; &#xAAA; &#xAAA; &#xAAA; &#xAAA; &#xAAA;
@@ -44,7 +35,35 @@ mod to_html {
     }
 
     #[bench]
-    fn pathological_codeblocks(b: &mut test::Bencher) {
+    fn pathological_emphasis(b: &mut test::Bencher) {
+        let input = std::iter::repeat("a***").take(1000).collect::<String>();
+
+        b.iter(|| render_html(&input, Options::empty()));
+    }
+
+    #[bench]
+    fn pathological_emphasis2(b: &mut test::Bencher) {
+        let input = std::iter::repeat("a***_b__").take(1000).collect::<String>();
+
+        b.iter(|| render_html(&input, Options::empty()));
+    }
+
+    #[bench]
+    fn pathological_emphasis3(b: &mut test::Bencher) {
+        let input = std::iter::repeat("[*_a").take(1000).collect::<String>();
+
+        b.iter(|| render_html(&input, Options::empty()));
+    }
+
+    #[bench]
+    fn pathological_strikethrough(b: &mut test::Bencher) {
+        let input = std::iter::repeat("a***b~~").take(2000).collect::<String>();
+
+        b.iter(|| render_html(&input, Options::empty()));
+    }
+
+    #[bench]
+    fn pathological_codeblocks1(b: &mut test::Bencher) {
         // Note that `buf` grows quadratically with number of
         // iterations. The point here is that the render time shouldn't
         // grow faster than that.
@@ -60,12 +79,20 @@ mod to_html {
     }
 
     #[bench]
-    fn more_pathological_codeblocks(b: &mut test::Bencher) {
+    fn pathological_codeblocks2(b: &mut test::Bencher) {
         let input = std::iter::repeat("\\``").take(1000).collect::<String>();
 
         b.iter(|| render_html(&input, Options::empty()));
     }
 
+    #[bench]
+    fn pathological_codeblocks3(b: &mut test::Bencher) {
+        let mut input = std::iter::repeat("`a`").take(4000).collect::<String>();
+        input.push('`');
+
+        b.iter(|| render_html(&input, Options::empty()));
+    }
+
     #[bench]
     fn pathological_hrules(b: &mut test::Bencher) {
         let mut input = std::iter::repeat("* ").take(2000).collect::<String>();
@@ -74,6 +101,13 @@ mod to_html {
         b.iter(|| render_html(&input, Options::empty()));
     }
 
+    #[bench]
+    fn pathological_link_titles(b: &mut test::Bencher) {
+        let input = std::iter::repeat("[ (](").take(2000).collect::<String>();
+
+        b.iter(|| render_html(&input, Options::empty()));
+    }
+
     #[bench]
     fn advanced_pathological_codeblocks(b: &mut test::Bencher) {
         // Note that `buf` grows quadratically with number of
