@@ -97,9 +97,15 @@ where
                     self.end_tag(tag)?;
                 }
                 Text(text) => {
-                    escape_html(&mut self.writer, &text, false)?;
+                    escape_html(&mut self.writer, &text)?;
                     self.end_newline = text.ends_with('\n');
                 }
+                Code(text) => {
+                    self.write(b"<code>", false)?;
+                    escape_html(&mut self.writer, &text)?;
+                    self.write(b"</code>", false)?;
+                    self.end_newline = false;
+                }
                 Html(html) | InlineHtml(html) => {
                     self.write(html.as_bytes(), false)?;
                 }
@@ -112,7 +118,7 @@ where
                 FootnoteReference(name) => {
                     let len = self.numbers.len() + 1;
                     self.write(b"<sup class=\"footnote-reference\"><a href=\"#", false)?;
-                    escape_html(&mut self.writer, &name, false)?;
+                    escape_html(&mut self.writer, &name)?;
                     self.write(b"\">", false)?;
                     let number = *self.numbers.entry(name).or_insert(len);
                     self.write(format!("{}", number).as_bytes(), false)?;
@@ -194,7 +200,7 @@ where
                     self.write(b"<pre><code>", false)
                 } else {
                     self.write(b"<pre><code class=\"language-", false)?;
-                    escape_html(&mut self.writer, lang, false)?;
+                    escape_html(&mut self.writer, lang)?;
                     self.write(b"\">", false)
                 }
             }
@@ -219,13 +225,12 @@ where
             Tag::Emphasis => self.write(b"<em>", false),
             Tag::Strong => self.write(b"<strong>", false),
             Tag::Strikethrough => self.write(b"<del>", false),
-            Tag::Code => self.write(b"<code>", false),
             Tag::Link(LinkType::Email, dest, title) => {
                 self.write(b"<a href=\"mailto:", false)?;
                 escape_href(&mut self.writer, &dest)?;
                 if !title.is_empty() {
                     self.write(b"\" title=\"", false)?;
-                    escape_html(&mut self.writer, &title, false)?;
+                    escape_html(&mut self.writer, &title)?;
                 }
                 self.write(b"\">", false)
             }
@@ -234,7 +239,7 @@ where
                 escape_href(&mut self.writer, &dest)?;
                 if !title.is_empty() {
                     self.write(b"\" title=\"", false)?;
-                    escape_html(&mut self.writer, &title, false)?;
+                    escape_html(&mut self.writer, &title)?;
                 }
                 self.write(b"\">", false)
             }
@@ -245,7 +250,7 @@ where
                 self.raw_text()?;
                 if !title.is_empty() {
                     self.write(b"\" title=\"", false)?;
-                    escape_html(&mut self.writer, &title, false)?;
+                    escape_html(&mut self.writer, &title)?;
                 }
                 self.write(b"\" />", false)
             }
@@ -253,7 +258,7 @@ where
                 self.fresh_line()?;
                 let len = self.numbers.len() + 1;
                 self.write(b"<div class=\"footnote-definition\" id=\"", false)?;
-                escape_html(&mut self.writer, &*name, false)?;
+                escape_html(&mut self.writer, &*name)?;
                 self.write(b"\"><sup class=\"footnote-definition-label\">", false)?;
                 let number = *self.numbers.entry(name).or_insert(len);
                 self.write(&*format!("{}", number).as_bytes(), false)?;
@@ -319,9 +324,6 @@ where
             Tag::Strikethrough => {
                 self.write(b"</del>", false)?;
             }
-            Tag::Code => {
-                self.write(b"</code>", false)?;
-            }
             Tag::Link(_, _, _) => {
                 self.write(b"</a>", false)?;
             }
@@ -346,14 +348,10 @@ where
                     }
                     nest -= 1;
                 }
-                Text(text) => {
-                    escape_html(&mut self.writer, &text, false)?;
-                    self.end_newline = text.ends_with('\n');
-                }
                 Html(_) => (),
-                InlineHtml(html) => {
-                    escape_html(&mut self.writer, &html, false)?;
-                    self.end_newline = html.ends_with('\n');
+                InlineHtml(text) | Code(text) | Text(text) => {
+                    escape_html(&mut self.writer, &text)?;
+                    self.end_newline = text.ends_with('\n');
                 }
                 SoftBreak | HardBreak => {
                     self.write(b" ", false)?;
@@ -411,6 +409,11 @@ where
 /// Iterate over an `Iterator` of `Event`s, generate HTML for each `Event`, and
 /// write it out to a writable stream.
 ///
+/// **Note**: using this function with an unbuffered writer like a file or socket
+/// will result in poor performance. Wrap these in a
+/// [`BufWriter`](https://doc.rust-lang.org/std/io/struct.BufWriter.html) to
+/// prevent unnecessary slowdowns.
+///
 /// # Examples
 ///
 /// ```
